==> deadbeef-0.4.4.tar.bz2: deadbeef-0.4.4/translation/extra.c <==
// this file should list extra translatable strings that are not referenced
// directly in source code, e.g. scripted plugin configuration strings
_("Add Audio CD")
_("Lookup on Last.fm")
// ALSA output plugin
_("Use ALSA resampling")
_("Release device while stopped")
_("Preferred buffer size")
_("Preferred period size")
// Last.fm plugin
_("Enable scrobbler")
_("Disable nowplaying")
_("Username")
_("Password")
_("Scrobble URL")
// Album Artwork plugin
_("Cache update period (hr)")
_("Fetch from embedded tags")
_("Fetch from local folder")
_("Local cover file mask")
_("Fetch from last.fm")
_("Fetch from albumart.org")
// Audio CD player
_("Use CDDB/FreeDB")
_("Prefer CD-Text over CDDB")
_("CDDB url (e.g. 'freedb.org')")
_("CDDB port number (e.g. '888')")
_("Prefer CDDB protocol over HTTP")
_("Enable NRG image support")
// DUMB module player plugin
_("Resampling quality (0..2, higher is better)")
// Game_Music_Emu decoder plugin
_("Max song length (in minutes)")
// Standard GTK2 user interface plugin
_("Ask confirmation to delete files from disk")
_("Status icon volume control sensitivity")
_("Custom status icon")
_("Run gtk_init with --sync (debug mode)")
// OSD Notify plugin
_("Notification format")
// PulseAudio output plugin
_("PulseAudio server")
_("Preferred buffer size")
_("Samplerate")
// SHN player plugin
_("Relative seek table path")
_("Absolute seek table path")
_("Swap audio bytes (toggle if all you hear is static)")
// SID decoder plugin
_("Enable HVSC")
_("HVSC path")
// WildMidi player plugin
_("Timidity++ bank configuration file")
// Track properties dialog
_("Artist")
_("Track Title")
_("Performer")
_("Band / Album Artist")
_("Album")
_("Date")
_("Track Number")
_("Total Tracks")
_("Genre")
_("Composer")
_("Disc Number")
_("Comment")
_("Encoder / Vendor")
_("Copyright")

==> deadbeef-0.5.0.tar.bz2: deadbeef-0.5.0/translation/extra.c <==
// this file should list extra translatable strings that are not referenced
// directly in source code, e.g. scripted plugin configuration strings
_("Add Audio CD")
_("Lookup on Last.fm")
// ALSA output plugin
_("Use ALSA resampling")
_("Release device while stopped")
_("Preferred buffer size")
_("Preferred period size")
// Last.fm plugin
_("Enable scrobbler")
_("Disable nowplaying")
_("Username")
_("Password")
_("Scrobble URL")
// OSS output plugin
_("Device file")
_("OSS4 samplerate bug workaround")
// Album Artwork plugin
_("Cache update period (hr)")
_("Fetch from embedded tags")
_("Fetch from local folder")
_("Local cover file mask")
_("Fetch from last.fm")
_("Fetch from albumart.org")
_("Scale artwork towards longer side")
// Audio CD player
_("Use CDDB/FreeDB")
_("Prefer CD-Text over CDDB")
_("CDDB url (e.g. 'freedb.org')")
_("CDDB port number (e.g. '888')")
_("Prefer CDDB protocol over HTTP")
_("Enable NRG image support")
// DUMB module player plugin
_("Resampling quality (0..2, higher is better)")
// Game_Music_Emu decoder plugin
_("Max song length (in minutes)")
// Standard GTK2 user interface plugin
_("Ask confirmation to delete files from disk")
_("Status icon volume control sensitivity")
_("Custom status icon")
_("Run gtk_init with --sync (debug mode)")
_("Add separators between plugin context menu items")
// OSD Notify plugin
_("Notification title format")
_("Notification content format")
_("Show album art")
_("Album art size (px)")
// PulseAudio output plugin
_("PulseAudio server")
_("Preferred buffer size")
_("Samplerate")
// SHN player plugin
_("Relative seek table path")
_("Absolute seek table path")
_("Swap audio bytes (toggle if all you hear is static)")
// SID decoder plugin
_("Enable HVSC Songlength DB")
_("Songlengths.txt (from HVSC)")
_("Bits per sample (8 or 16)")
_("Default song length (sec)")
// WildMidi player plugin
_("Timidity++ bank configuration file")
// Track properties dialog
_("Artist")
_("Track Title")
_("Performer")
_("Band / Album Artist")
_("Album")
_("Date")
_("Track Number")
_("Total Tracks")
_("Genre")
_("Composer")
_("Disc Number")
_("Comment")
_("Encoder / Vendor")
_("Copyright")
_("Location")
_("Subtrack Index")
_("Tag Type(s)")
_("Embedded Cuesheet")
_("Codec")
// FFmpeg deocder plugin
_("File Extensions (separate with ';')")
//Converter GUI
_("Convert")
// Resampler (Secret Rabbit Code)
_("Target Samplerate")
_("Quality / Algorythm")
